@@ -6,6 +6,8 @@ go mod vendor
 # Download only the dependencies that are not yet available in Debian
 MODULES=(
   "github.com/micro-editor/terminal"
+  "github.com/micro-editor/tcell/v2"
+  "github.com/micro-editor/json5"
 )
 
 # Loop through each module
